<?php


namespace Schaffen\Core\Form\Managers;


use Freelabois\LaravelQuickstart\Extendables\ManipulationManager;
use Illuminate\Support\Facades\Storage;
use Schaffen\Core\Form\Models\Field;
use Schaffen\Core\Form\Repositories\FormAssociationRepository;
use Schaffen\Core\Form\Repositories\FormRepository;

class FormAssociationManager extends ManipulationManager
{
    private $key = 0;

    public function __construct(FormAssociationRepository $repository)
    {
        parent::__construct($repository);
    }

    public function answerFormFromEntity(array $answer, int $entity_id, int $form_id, $type = 'service-order')
    {
        $form_repository = app()->make(FormRepository::class);
        $form_db = $form_repository->find($form_id);
        $association_to_answer = $this->repository->firstOrNew([
            "foa_formeavel_tipo" => $type,
            "foa_formeavel_codigo" => $entity_id,
            "foa_fk_form_codigo" => $form_id
        ], [], [["name" => 'form', "model" => $form_db]]);

        return $this->answerForm($answer, $association_to_answer->foa_codigo, [["name" => 'form', "model" => $form_db]]);

    }

    public function answerForm(array $answers, int $association_id, array $relations)
    {

        foreach ($answers as $foa_resposta_key => $foa_resposta) {
            /*
             * Todas as imagens vem como array, outras respostas vem como string
             * Salva as imagens no storage e persiste o path dela separado por vírgula
             */
            if (in_array($foa_resposta['cam_tipo'], Field::$images)) {
                if (!empty($foa_resposta['foa_resposta']) ?? NULL) {
                    $answers_path = $this->saveFiles($foa_resposta['foa_resposta'], $association_id, $foa_resposta['cam_codigo']);
                    $answers[$foa_resposta_key]['foa_resposta'] = $answers_path;
                }
            }
        }

        return $this->repository->storeOrUpdate(['foa_respostas' => json_encode($answers)], $association_id, $relations);
    }

    public function saveFiles($resposta, $association_id, $cam_codigo)
    {
        $answers_path = "";
        if (is_array($resposta))
            foreach ($resposta as $answer)
                $answers_path .= $this->saveFiles($answer, $association_id, $cam_codigo) . ',';
        if (is_string($resposta)) {
            if (str_contains($resposta, env('APP_URL')) || str_contains($resposta, "https://zeus.schaffen-it.com")) {
                $answers_path = str_replace(env('APP_URL'), "", $resposta);
                $answers_path = str_replace("https://zeus.schaffen-it.com", "", $answers_path);
            } else {
                $answer = $resposta;
                $answer = str_replace("[", "", $answer);
                $answer = str_replace("]", "", $answer);
                //Transforma base64 em imagem PNG
                [$type, $data] = explode(';', $answer);
                [, $data] = explode(',', $data);
                [, $type] = explode('/', $type);
                $data = base64_decode($data);
                $path = '/public/answers/' . $association_id . '_' . $cam_codigo . '_' . $this->key++ . '.' . $type;
                Storage::put($path, $data);
                $answers_path .= $path . ',';
            }
        }
        return $answers_path;
    }

}
